import type { PlaywrightTestConfig } from '@playwright/test'
import { devices } from '@playwright/test'

/**
 * Read environment variables from file.
 * https://github.com/motdotla/dotenv
 */
// require('dotenv').config();

const baseURL = process.env.BASE_URL || 'https://staging.web.project-holi.org'

/**
 * See https://playwright.dev/docs/test-configuration.
 */
const config: PlaywrightTestConfig = {
  testDir: './tests',
  /* Maximum time one test can run for. */
  timeout: 60 * 1000,
  expect: {
    /**
     * Maximum time expect() should wait for the condition to be met.
     * For example in `await expect(locator).toHaveText();`
     */
    timeout: 5000,
  },
  /* Run tests in files in parallel */
  fullyParallel: true,
  /* Fail the build on CI if you accidentally left test.only in the source code. */
  forbidOnly: !!process.env.CI,
  /* Retry on CI leads to us devs not fixing flaky tests, therefore deactivated */
  retries: 1,
  /* Opt out of parallel tests on CI. */
  // workers: process.env.CI ? 1 : undefined,
  // parallel tests cause flakiness
  workers: 1,
  /* Reporter to use. See https://playwright.dev/docs/test-reporters */
  reporter: [['html', { open: 'never' }]],
  /* Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions. */
  use: {
    /* Maximum time each action such as `click()` can take. Defaults to 0 (no limit). */
    actionTimeout: 0,
    /* Base URL to use in actions like `await page.goto('/')`. */
    baseURL: baseURL,

    /* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
    trace: 'on',
    screenshot: 'only-on-failure',
    video: 'on-first-retry',
    headless: process.env.CI ? true : !!process.env.HEADLESS || true,
  },

  /* Configure projects for major browsers */
  projects: [
    /* Test against desktop viewports. */
    // {
    //   name: 'chromium',
    //   use: {
    //     ...devices['Desktop Chrome'],
    //   },
    // },

    // {
    //   name: 'firefox',
    //   use: {
    //     ...devices['Desktop Firefox'],
    //   },
    // },

    {
      name: 'webkit',
      use: {
        ...devices['Desktop Safari'],
        viewport: { width: 390, height: 844 },
      },
    },

    /* Test against mobile viewports. */
    {
      name: 'Mobile_Chrome',
      use: {
        ...devices['Pixel 5'],
      },
    },

    /**
     * Mobile Safari has an issue when running on Playwright's official docker image and
     * is leading to flakiness, with a problem debugging/tracing it:
     * https://github.com/microsoft/playwright/issues/11812
     */
    // {
    //   name: 'Mobile_Safari',
    //   use: {
    //     ...devices['iPhone 12'],
    //   },
    // },
    //{
    //  name: 'Mobile_Firefox',
    //  use: {
    //    ...devices['Desktop Firefox'],
    //    viewport: { width: 390, height: 844 },
    //    deviceScaleFactor: 3,
    //  },
    //},

    /* Test against branded browsers. */
    // {
    //   name: 'Microsoft_Edge',
    //   use: {
    //     channel: 'msedge',
    //   },
    // },
    // {
    //   name: 'Google Chrome',
    //   use: {
    //     channel: 'chrome',
    //   },
    // },
  ],

  /* Folder for test artifacts such as screenshots, videos, traces, etc. */
  // outputDir: 'test-results/',

  /* Run your local dev server before starting the tests */
  // webServer: {
  //   command: 'npm run start',
  //   port: 3000,
  // },
}

export default config
