import * as React from 'react'
import { StyleProp, StyleSheet, Text, TextProps, TextStyle } from 'react-native'

import { colors } from '@holi/ui/styles/globalVars'
import { HoliTheme, useTheme } from '@holi/ui/styles/theme'

type HoliTextSize = 'extralarge' | 'large' | 'default' | 'small' | 'extrasmall' // for working code completion in vscode
export const HoliTextSizes: HoliTextSize[] = ['large', 'default', 'small', 'extrasmall'] // keep in sync with all possible HoliTextSize values

export interface HoliTextProps extends TextProps {
  children?: React.ReactNode
  size?: HoliTextSize
  bold?: boolean
  style?: StyleProp<TextStyle>
  selectable?: boolean
  testID?: string
  numberOfLines?: number
}

const HoliText = ({ children, size = 'default', bold = false, selectable = true, ...props }: HoliTextProps) => {
  const { theme } = useTheme()
  const styles = getStyles(theme)

  return (
    <Text
      accessible={false}
      {...props}
      selectable={selectable}
      testID={props?.testID}
      style={[styles.base, styles[size as keyof typeof styles], bold && styles.bold, props.style]}
    >
      {children}
    </Text>
  )
}

export default HoliText

const getStyles = (theme: HoliTheme) =>
  StyleSheet.create({
    base: {
      fontWeight: '400',
      fontFamily: theme.fontFamily.default('Book'),
      color: colors.softblack,
    },
    extralarge: {
      fontSize: 28,
      lineHeight: 28 * 1.2,
    },
    large: {
      fontSize: 21,
      lineHeight: 21 * 1.2,
    },
    default: {
      fontSize: 16,
      lineHeight: 16 * 1.2,
    },
    small: {
      fontSize: 14,
      lineHeight: 14 * 1.2,
    },
    extrasmall: {
      fontSize: 12,
      lineHeight: 12 * 1.2,
    },
    bold: {
      fontWeight: '500',
      fontFamily: theme.fontFamily.default('Medium'),
    },
  })
