import React, { useCallback } from 'react'
import { Platform } from 'react-native'

import { HoliTheme } from '.'
import { useStyleMixins } from './mixins'
import defaultTheme, { ThemeContext } from './theme'

export const ThemeProvider: React.FunctionComponent<{
  theme?: HoliTheme
}> = ({ children, theme = defaultTheme }) => {
  const [isDark, toggleDarkMode] = React.useReducer((isDark) => !isDark, defaultTheme.dark)
  const [modalIsOpen, setModalIsOpen] = React.useState(false)
  const mixins = useStyleMixins()

  const setModalIsOpenWeb = useCallback((isOpen: boolean) => {
    if (Platform.OS === 'web') {
      document.body.style.overflow = isOpen ? 'hidden' : ''
    }

    setModalIsOpen?.(isOpen)
  }, [])

  return (
    <ThemeContext.Provider
      value={{
        theme: { ...theme, dark: isDark, mixins },
        toggleDarkMode,
        modalIsOpen,
        setModalIsOpen: setModalIsOpenWeb,
      }}
    >
      {children}
    </ThemeContext.Provider>
  )
}
